@@ -1,14 +1,53 @@
 use warnings;
 use strict;
 package Object::Annotate;
-{
-  $Object::Annotate::VERSION = '0.024';
-}
 # ABSTRACT: mix in logging-to-database to objects (deprecated)
-
+$Object::Annotate::VERSION = '0.025';
 use Carp ();
 use UNIVERSAL::moniker 0.01;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod B<Achtung!>  This library was an experiment.  It failed.  Consider using
+#pod L<Mixin::ExtraFields> instead.
+#pod
+#pod   package Your::Class;
+#pod   use Object::Annotate annotate => { dsn => '...', table => 'notes' };
+#pod
+#pod   ...
+#pod
+#pod   my $object = Your::Class->new( ... );
+#pod   $object->annotate({ event => "created", comment => "(as example)" });
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Object::Annotate is a mixin that provides any class with method for storing
+#pod and retrieving notes about its objects.  It can also produce objects which
+#pod exist only to store annotations about abstract (uninstantiated) objects,
+#pod procedures, or concepts.
+#pod
+#pod =head1 USAGE
+#pod
+#pod To mix Object::Annotate into a class, just C<use> it.  To create a classless
+#pod annotator object, use Object::Annotate's C<new> method.  Both of these usages
+#pod accept the same arguments:
+#pod
+#pod   db        - options for the database in which notes are stored; a hashref:
+#pod
+#pod     dsn       - the DSN to pass to Class::DBI to create a connection
+#pod     user      - the username to use in connecting to the database
+#pod     pass      - the password to use in connecting to the database
+#pod     table     - the table in which annotations are stored
+#pod     sequence  - if given, the Class::DBI table's primary key values comes from
+#pod                 this sequence; see L<Class::DBI> for more information
+#pod
+#pod   columns   - columns for the annotation table
+#pod   obj_class - the class name to use for annotations for this class
+#pod               (defaults to Class->moniker, see UNIVERSAL::moniker)
+#pod   id_attr   - the object attribute to use for "id"; called as a method
+#pod               if it's a scalar ref, it's de-ref'd and used as a constant string
+#pod
+#pod =cut
 
 # We'll store the constructed Class::DBI subclasses here.
 # $class_for->{ $dsn }->{ $table } = $class
@@ -29,6 +68,15 @@ use Sub::Exporter 0.92 -setup => {
   groups => { annotator => \&setup_class },
 };
 
+#pod =head2 new
+#pod
+#pod You can use the C<new> method to create a singularity -- an object that can
+#pod annotate as if it was of a class that used Object::Annotate, but is of its own
+#pod unique class.
+#pod
+#pod   my $notepad = Object::Annotate->new({ db => { ... } });
+#pod
+#pod =cut
 
 sub new {
   my ($self, $arg) = @_;
@@ -43,7 +91,53 @@ sub new {
   bless $singularity => $target;
 }
 
+#pod =head1 METHODS
+#pod
+#pod These methods are not provided by Object::Annotate, but are installed into
+#pod classes that use Object::Annotate.
+#pod
+#pod =head2 annotations_class
+#pod
+#pod   my $annotations_class = Your::Class->annotations_class;
+#pod
+#pod This method returns the name of the automatically constructed class that
+#pod handles annotations for the class or object on which it is installed.
+#pod
+#pod =head2 annotate
+#pod
+#pod   $object->annotate({
+#pod     event => 'update',
+#pod     attr  => 'priority',
+#pod     old_val => 1,
+#pod     new_val => 3,
+#pod   });
+#pod
+#pod This method creates an annotation for the object on which it is called.
+#pod
+#pod =head2 search_annotations
+#pod
+#pod   # search all annotations for this class
+#pod   my @notes = Class->search_annotations({ event => 'explosion' });
+#pod
+#pod   # searches only annotations for this object
+#pod   my @notes = $object->search_annotations({ event => 'explosion' });
+#pod
+#pod This method searches through the annotations for a class or an object, using
+#pod the Class::DBI C<search> method.
+#pod
+#pod =cut
 
+#pod =head1 INTERNALS
+#pod
+#pod =head2 setup_class
+#pod
+#pod   Object::Annotate->setup_class('annotator', \%arg, \%col);
+#pod
+#pod This method does the heavy lifting needed to turn the class named by C<$target>
+#pod into one that does annotation.  It is a group generator as described in
+#pod L<Sub::Exporter>.
+#pod
+#pod =cut
 
 sub setup_class {
   my ($self, $name, $arg, $col) = @_;
@@ -87,6 +181,20 @@ sub setup_class {
   };
 }
 
+#pod =head2 class_for
+#pod
+#pod   my $class = Object::Annotate->class_for(\%arg);
+#pod
+#pod This method returns the class to use for the described database and table,
+#pod constructing it (see C<L</construct_class>>) if needed.
+#pod
+#pod Valid arguments are (for all, see the L</USAGE> section): dsn, table, db_user,
+#pod db_pass, sequence
+#pod
+#pod See the L</USAGE> section, above, for information on these arguments, which
+#pod typically are passed along by the import routine.
+#pod
+#pod =cut
 
 sub class_for {
   my ($self, $arg) = @_;
@@ -121,6 +229,24 @@ sub class_for {
   return $class;
 }
 
+#pod =head2 default_dsn
+#pod
+#pod =head2 default_table
+#pod
+#pod =head2 default_user
+#pod
+#pod =head2 default_pass
+#pod
+#pod These methods return the default database settings to use if none is specified
+#pod when importing Object::Annotate.  The built-in behavior is to return the
+#pod OBJ_ANNOTATE_DSN, OBJ_ANNOTATE_TABLE, etc. environment variables.
+#pod
+#pod =head2 default_base_class
+#pod
+#pod This method returns the class from which the annotator subclass will inherit.
+#pod It defaults to Class::DBI.
+#pod
+#pod =cut
 
 sub default_dsn   { $ENV{OBJ_ANNOTATE_DSN};   }
 sub default_table { $ENV{OBJ_ANNOTATE_TABLE}; }
@@ -130,6 +256,23 @@ sub default_base_class  { 'Class::DBI' }
 
 sub _default_sequence {  }
 
+#pod =head2 construct_cdbi_class
+#pod
+#pod   my $new_class = Object::Annotate->construct_cdbi_class(\%arg);
+#pod
+#pod This method sets up a new Class::DBI subclass that will store in the database
+#pod described by the arguments.
+#pod
+#pod Valid arguments are:
+#pod
+#pod   dsn     - the dsn for the database in which to store
+#pod   user    - the database user as whom to connect
+#pod   pass    - the database password
+#pod   table   - the table in which to store annotations
+#pod   columns - the extra columns for the table
+#pod   base_class - class from which the new class inherits (default: Class::DBI)
+#pod
+#pod =cut
 
 sub construct_cdbi_class {
   my ($class, $arg) = @_;
@@ -164,6 +307,21 @@ sub construct_cdbi_class {
   return $class_for->{ $arg->{dsn} || '' }->{ $arg->{table} } = $new_class;
 }
 
+#pod =head2 build_annotator
+#pod
+#pod   my $code = Object::Annotate->build_annotator(\%arg);
+#pod
+#pod This builds the routine that will be installed as "annotate" in the importing
+#pod class.  It returns a coderef.
+#pod
+#pod It takes the following arguments:
+#pod
+#pod   obj_class - the class name to use for this class's log entries
+#pod   id_attr   - the method to use to get object ids; if a scalar ref,
+#pod               the dereferenced string is used as a constant
+#pod   set_time  - if true, the created value will be created as the current time
+#pod
+#pod =cut
 
 sub build_annotator {
   my ($self, $arg) = @_;
@@ -213,6 +371,20 @@ sub build_annotator {
   return $annotator;
 }
 
+#pod =head2 build_searcher
+#pod
+#pod   my $code = Object::Annotate->build_searcher(\%arg);
+#pod
+#pod This builds the routine that will be installed as "search_annotations" in the
+#pod importing class.  It returns a coderef.
+#pod
+#pod It takes the following arguments:
+#pod
+#pod   obj_class - the class name to use for this class's log entries
+#pod   id_attr   - the method to use to get object ids; if a scalar ref,
+#pod               the dereferenced string is used as a constant
+#pod
+#pod =cut
 
 sub build_searcher {
   my ($self, $arg) = @_;
@@ -249,13 +421,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Object::Annotate - mix in logging-to-database to objects (deprecated)
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -427,6 +601,22 @@ It takes the following arguments:
 
 Ricardo SIGNES <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Ricardo SIGNES
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Ricardo SIGNES <rjbs@codesimply.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2006 by Ricardo SIGNES.
