@@ -9,11 +9,11 @@ CREATE TABLE annotations (
   new_val   varchar(255),         -- what is new value?
   via       varchar(80),          -- what caused the change?
   comment   varchar(255),         -- the annotation, if any
-  note_time timestamp             -- when the annotation was made
+  created   timestamp(0)          -- when the annotation was made
             with time zone
             NOT NULL
             DEFAULT current_timestamp,
-  expire_time timestamp           -- when the annotation was made
+  expire_time timestamp(0)        -- when the annotation was made
             with time zone        -- this may be null, for "never expire"
             NOT NULL
             DEFAULT 'infinity'
